@@ -5,53 +5,33 @@ use 5.006002;
 use strict;
 use warnings;
 
-use Exporter;
-
-our @ISA = qw{ Exporter };
-
+use Exporter qw{ import };
 use HTTP::Date;
-use HTTP::Status qw{ :constants };
 use Test::More 0.96;	# For subtest
 
-our $VERSION = '0.179_002';
+our $VERSION = '0.085';
 
 # Set the following to zero if Space Track (or any other SSL host)
 # starts using a certificate that can not be verified.
-use constant VERIFY_HOSTNAME => defined $ENV{SPACETRACK_VERIFY_HOSTNAME}
-    ? $ENV{SPACETRACK_VERIFY_HOSTNAME}
-    : 0;
+use constant VERIFY_HOSTNAME => 1;
 
-our @EXPORT =		## no critic (ProhibitAutomaticExportation)
-qw{
+our @EXPORT = qw{
     is_error
-    is_error_or_skip
     is_not_success
     is_success
-    is_success_or_skip
     last_modified
     most_recent_http_response
     not_defined
     site_check
-    spacetrack_user
-    spacetrack_skip_no_prompt
+    spacetrack_account
     skip_site
     throws_exception
     VERIFY_HOSTNAME
 };
 
-use constant HASH_REF	=> ref {};
-use constant REGEXP_REF	=> ref qr{};
-
-use constant NO_SPACE_TRACK_ACCOUNT => 'No Space-Track account provided';
-
-# Deliberately not localized, to prevent unwanted settings from sneaking
-# in from the user's identity file.
-$Astro::SpaceTrack::SPACETRACK_IDENTITY_KEY = {
-    map { $_ => 1 } qw{ username password } };
-
 my $rslt;
 
-sub is_error {		## no critic (RequireArgUnpacking)
+sub is_error (@) {		## no critic (RequireArgUnpacking)
     my ( $obj, $method, @args ) = @_;
     my ( $code, $name ) = splice @args, -2, 2;
     $rslt = eval { $obj->$method( @args ) };
@@ -63,19 +43,7 @@ sub is_error {		## no critic (RequireArgUnpacking)
     goto &ok;
 }
 
-sub is_error_or_skip {		## no critic (RequireArgUnpacking)
-    my ( $obj, $method, @args ) = @_;
-    local $Test::Builder::Level = $Test::Builder::Level + 1;
-    my ( $code, $name ) = splice @args, -2, 2;
-    $rslt = eval { $obj->$method( @args ) };
-    $rslt
-	or return fail "$name threw exception: $@";
-    my $got = $rslt->code();
-    __skip_if_server_error( $method, $got );
-    return cmp_ok $got, '==', $code, $name;
-}
-
-sub is_not_success {	## no critic (RequireArgUnpacking)
+sub is_not_success (@) {	## no critic (RequireArgUnpacking)
     my ( $obj, $method, @args ) = @_;
     my $name = pop @args;
     $rslt = eval { $obj->$method( @args ) };
@@ -87,7 +55,7 @@ sub is_not_success {	## no critic (RequireArgUnpacking)
     goto &ok;
 }
 
-sub is_success {	## no critic (RequireArgUnpacking)
+sub is_success (@) {	## no critic (RequireArgUnpacking)
     my ( $obj, $method, @args ) = @_;
     my $name = pop @args;
     $rslt = eval { $obj->$method( @args ) }
@@ -101,27 +69,6 @@ sub is_success {	## no critic (RequireArgUnpacking)
     goto &ok;
 }
 
-sub is_success_or_skip {	## no critic (RequireArgUnpacking)
-    my ( $obj, $method, @args ) = @_;
-    local $Test::Builder::Level = $Test::Builder::Level + 1;
-    my $skip = pop @args;
-    $skip =~ m/ [^0-9] /smx
-	and fail "Skip number '$skip' not numeric";
-    my $name = pop @args;
-    $rslt = eval { $obj->$method( @args ) } or do {
-	fail "$name threw exception: $!" ;
-	skip "$method() threw exception", $skip;
-    };
-    __skip_if_server_error( $method, $rslt->code(), $skip );
-    ok $rslt->is_success(), $name
-	or do {
-	diag $rslt->status_line();
-	skip "$method() failed", $skip;
-    };
-    return 1;
-}
-
-
 sub last_modified {
     $rslt
 	or return;
@@ -135,7 +82,7 @@ sub most_recent_http_response {
     return $rslt;
 }
 
-sub not_defined {
+sub not_defined ($$) {
     @_ = ( ! defined $_[0], @_[1 .. $#_] );
     goto &ok;
 }
@@ -153,16 +100,12 @@ sub not_defined {
 	    1;
 	} or $set_read_mode = sub {};
 
-	local $@ = undef;
-	eval {		## no critic (RequireCheckingReturnValueOfEval)
-	    require IO::Handle;
-	    STDERR->autoflush( 1 );
-	};
+	STDERR->autoflush( 1 );
     }
 
-    sub prompt {
+    sub prompt (@) {
 	my @args = @_;
-	my $opt = HASH_REF eq ref $args[0] ? shift @args : {};
+	my $opt = 'HASH' eq ref $args[0] ? shift @args : {};
 	$readkey_loaded
 	    or not $opt->{password}
 	    or push @args, '(ECHOED)';
@@ -183,7 +126,6 @@ sub not_defined {
 
 }
 
-
 # Determine whether a given web site is to be skipped.
 
 {
@@ -191,22 +133,24 @@ sub not_defined {
     my %skip_site;
     BEGIN {
 	%info = (
-	    'celestrak.org'	=> {
-		url	=> 'https://celestrak.org/',
+	    'celestrak.com'	=> {
+		url	=> 'http://celestrak.com/',
 	    },
 	    'mike.mccants'	=> {
-		# url	=> 'http://www.prismnet.com/~mmccants/',
-		url	=> 'https://www.mmccants.org/',
+		url	=> 'http://www.prismnet.com/~mmccants/tles/iridium.html',
 	    },
 	    'rod.sladen'	=> {
 		url	=> 'http://www.rod.sladen.org.uk/iridium.htm',
 	    },
+	    'spaceflight.nasa.gov'	=> {
+		url	=> 'http://spaceflight.nasa.gov',
+	    },
 	    'www.amsat.org'	=> {
-		url	=> 'https://www.amsat.org/',
+		url	=> 'http://www.amsat.org/',
 	    },
 	    'www.space-track.org'	=> {
 		url	=> 'https://www.space-track.org/',
-		check	=> \&__spacetrack_skip,
+		check	=> \&spacetrack_skip,
 	    }
 	);
 
@@ -218,19 +162,9 @@ sub not_defined {
 	    }
 	}
     }
-
-    sub __site_to_check_uri {
-	my ( $site ) = @_;
-	return $info{$site}{url};
-    }
-
-    sub __site_codes {
-	return sort keys %info;
-    }
-
     my $ua;
 
-    sub set_skip {
+    sub set_skip ($;$) {
 	my ( $site, $skip ) = @_;
 	exists $info{$site}{url}
 	    or die "Programming error. '$site' unknown";
@@ -238,17 +172,10 @@ sub not_defined {
 	return;
     }
 
-    sub site_check {
-	my @sites = @_;
-	my @rslt = grep { defined $_ } map { _site_check( $_ ) } @sites
-	    or return;
-	return join '; ', @rslt;
-    }
-
-    sub _site_check {
+    sub site_check ($) {
 	my ( $site ) = @_;
 	exists $skip_site{$site} and return $skip_site{$site};
-	my $url = __site_to_check_uri( $site ) or do {
+	my $url = $info{$site}{url} or do {
 	    my $skip = "Programming error - No known url for '$site'";
 	    diag( $skip );
 	    return ( $skip_site{$site} = $skip );
@@ -263,10 +190,10 @@ sub not_defined {
 	}
 
 	$ua ||= LWP::UserAgent->new(
-	    agent	=> 'curl/7.77.0',
 	    ssl_opts	=> { verify_hostname => VERIFY_HOSTNAME },
 	);
 	my $rslt = $ua->get( $url );
+	Astro::SpaceTrack::__tweak_response( $rslt );
 	$rslt->is_success()
 	    or return ( $skip_site{$site} =
 		"$site not available: " . $rslt->status_line() );
@@ -277,75 +204,19 @@ sub not_defined {
     }
 }
 
-{
-    my @is_server_error;
-
-    BEGIN {
-	foreach my $inx (
-	    HTTP_INTERNAL_SERVER_ERROR,
-	) {
-	    $is_server_error[$inx] = 1;
-	}
-    }
-
-    sub __skip_if_server_error {
-	my ( $method, $code, $skip ) = @_;
-	$is_server_error[$code]
-	    or return;
-	skip "$method() encountered server error $code", ( $skip || 0 ) + 1;
-    }
-}
-
-sub __spacetrack_identity {
-    # The following needs to be armor-plated so that a compilation
-    # failure does not shut down the testing system (though maybe it
-    # should!)
-    local $@ = undef;
-    return eval {	## no critic (RequireCheckingReturnValueOfEval)
-	local @INC = @INC;
-	require blib;
-	blib->import();
-	require Astro::SpaceTrack;
-	-f Astro::SpaceTrack->__identity_file_name()
-	    or return;
-	# Ad-hocery. Under Mac OS X the GPG machinery seems not to work in
-	# an SSH session; a dialog pops up which the originator of the
-	# session has no way to respond to. If the dialog is actually
-	# executed, the primary user's information gets clobbered. If
-	# the identity file is not binary, we assume we don't need GPG,
-	# because that is what Config::Identity assumes.
-	Astro::SpaceTrack->__identity_file_is_encrypted()
-	    and $ENV{SSH_CONNECTION}
-	    and return;
-	my $id = Astro::SpaceTrack->__spacetrack_identity();
-	defined $id->{username} && defined $id->{password} &&
-	    "$id->{username}/$id->{password}";
-    };
-    return;
-}
-
 {
     my $spacetrack_auth;
 
-    sub __spacetrack_skip {
-	my ( %arg ) = @_;
+    sub spacetrack_account {
+	return $spacetrack_auth;
+    }
+
+    sub spacetrack_skip {
 	defined $spacetrack_auth
-	    or $spacetrack_auth = $ENV{SPACETRACK_USER};
-	defined $spacetrack_auth
-	    and $spacetrack_auth =~ m< \A [:/] \z >smx
-	    and return NO_SPACE_TRACK_ACCOUNT;
-	$spacetrack_auth
 	    and return;
+	$spacetrack_auth = $ENV{SPACETRACK_USER} and return;
 	$ENV{AUTOMATED_TESTING}
 	    and return 'Automated testing and SPACETRACK_USER not set.';
-	$spacetrack_auth = __spacetrack_identity()
-	    and do {
-	    $arg{envir}
-		and $ENV{SPACETRACK_USER} = $spacetrack_auth; ## no critic (RequireLocalizedPunctuationVars)
-	    return;
-	};
-	$arg{no_prompt}
-	    and return $arg{no_prompt};
 	$^O eq 'VMS' and do {
 	    warn <<'EOD';
 
@@ -354,16 +225,14 @@ name SPACETRACK_USER. This should be set to your Space Track username
 and password, separated by a slash ("/") character.
 
 EOD
-	    return 'No Space-Track account provided.';
+	    return;
 	};
 	warn <<'EOD';
 
 Several tests require the username and password of a registered Space
 Track user. Because you have not provided environment variable
-SPACETRACK_USER, you will be prompted for this information. The password
-will be echoed unless Term::ReadKey is installed and supports ReadMode.
-If you leave either username or password blank, the tests will be
-skipped.
+SPACETRACK_USER, you will be prompted for this information. If you
+leave either username or password blank, the tests will be skipped.
 
 If you set environment variable SPACETRACK_USER to your Space Track
 username and password, separated by a slash ("/") character, that
@@ -378,37 +247,17 @@ EOD
 
 	my $user = prompt( 'Space-Track username' )
 	    and my $pass = prompt( { password => 1 }, 'Space-Track password' )
-	    or do {
-	    $ENV{SPACETRACK_USER} = '/'; ## no critic (RequireLocalizedPunctuationVars)
-	    return NO_SPACE_TRACK_ACCOUNT;
-	};
-	$ENV{SPACETRACK_USER} = $spacetrack_auth = "$user/$pass"; ## no critic (RequireLocalizedPunctuationVars)
+	    or return 'No Space-Track account provided.';
+	$spacetrack_auth = "$user/$pass";
 	return;
     }
 }
 
-sub spacetrack_skip_no_prompt {
-    my $skip;
-    $ENV{SPACETRACK_TEST_LIVE}
-	or plan skip_all => 'SPACETRACK_TEST_LIVE not set';
-    defined( $skip = __spacetrack_skip(
-	    envir	=> 1,
-	    no_prompt	=> NO_SPACE_TRACK_ACCOUNT,
-	)
-    ) and plan skip_all => $skip;
-    return;
-}
-
-sub spacetrack_user {
-    __spacetrack_skip( envir => 1 );
-    return;
-}
-
-sub throws_exception {	## no critic (RequireArgUnpacking)
+sub throws_exception (@) {	## no critic (RequireArgUnpacking)
     my ( $obj, $method, @args ) = @_;
     my $name = pop @args;
     my $exception = pop @args;
-    REGEXP_REF eq ref $exception
+    'Regexp' eq ref $exception
 	or $exception = qr{\A$exception};
     $rslt = eval { $obj->$method( @args ) }
 	and do {
@@ -475,15 +324,6 @@ HTTP::Response object. The arguments are:
   - The expected HTTP status code
   - The test name
 
-=head2 is_error_or_skip
-
- is_error $st, fubar => 42,
-     404,
-     'Make sure $st->fubar( 42 ) returns a 404';
-
-This subroutine is like C<is_error(), but if the returned status is 500,
-the test is skipped.
-
 =head2 is_not_success
 
  is_not_success $st, fubar => 42,
@@ -512,17 +352,6 @@ arguments are:
   - Zero or more arguments
   - The test name
 
-=head2 is_success_or_skop
-
- is_success_or_skip $st, fubar => 42,
-     'Make sure $st->fubar( 42 ) succeeds', 3;
-
-This subroutine is like C<is_success>, but if a problem occurs the
-number of tests given by the last argument is skipped. The skip argument
-assumes that the current test is B<not> skipped. If a 500 error is
-encountered, the current test B<is> skipped, and the number of tests
-skipped is the skip argument plus 1.
-
 =head2 last_modified
 
 This subroutine returns the value of the C<Last-Modified> header from
@@ -548,8 +377,8 @@ defined. The second argument is the test name.
 
 =head2 set_skip
 
- set_skip 'celestrak.org';
- set_skip 'celestrak.org', 'Manually skipping';
+ set_skip 'spaceflight.nasa.gov';
+ set_skip 'spaceflight.nasa.gov', 'Manually skipping';
 
 This subroutine sets or clears the skip indicator for the given site.
 The first argument is the site name, which must appear on the list
@@ -558,22 +387,26 @@ and represents the skip message, if any.
 
 =head2 site_check
 
- site_check 'www.amsat.org', 'celestrak.org';
+ site_check 'spaceflight.nasa.gov'
 
-This subroutine tests a preselected URL on the given sites, and sets the
+This subroutine tests a preselected URL on the given site, and sets the
 skip indicator appropriately. Allowed site names are:
 
- celestrak.org
+ celestrak.com
  mike.mccants
  rod.sladen
+ spaceflight.nasa.gov
  www.amsat.org
  www.space-track.org
 
-=head2 spacetrack_user
+=head2 spacetrack_account
 
-If C<$ENV{SPACETRACK_USER}> is not set, this subroutine sets it to
-whatever value is obtained from the identity file if available, or by
-prompting the user. The environment variable is B<not> localized.
+ $ENV{SPACETRACK_USER} = spacetrack_account
+
+This subroutine returns the Space Track user name and password in a
+format appropriate for the SPACETRACK_USER environment variable. The
+return is not valid unless C<site_check 'www.space-track.org'> has been
+called.
 
 =head2 throws_exception
 
@@ -597,9 +430,7 @@ the exception text.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-SpaceTrack>,
-L<https://github.com/trwyant/perl-Astro-SpaceTrack/issues/>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -607,11 +438,11 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014-2026 by Thomas R. Wyant, III
+Copyright (C) 2014 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
-of the licenses in the files F<LICENSE-Artistic> and F<LICENSE-GPL>.
+of the licenses in the directory LICENSES.
 
 This program is distributed in the hope that it will be useful, but
 without any warranty; without even the implied warranty of
